@@ -4,7 +4,7 @@
 # License           : MIT license <Check LICENSE>
 # Author            : Anderson Ignacio da Silva (aignacio) <anderson@aignacio.com>
 # Date              : 06.02.2023
-# Last Modified Date: 26.02.2023
+# Last Modified Date: 12.03.2023
 import logging
 import argparse
 import pathlib
@@ -15,9 +15,11 @@ from ipsocgen.common.validate import validate_config
 from ipsocgen.common.modules import *
 from ipsocgen.common.generate import *
 
-def _gen(cfg, output):
+def _gen(cfg, output, mmap):
     if cfg['type'] == 'soc':
-        soc_gen(cfg['soc_desc'], cfg['proj_name'], cfg['desc'], output)
+        soc_gen(cfg['soc_desc'], cfg['proj_name'], cfg['desc'], output, mmap)
+    else:
+        mpsoc_gen(cfg['mpsoc_desc'], cfg['proj_name'], cfg['desc'], output, mmap)
 
     return True
 
@@ -28,6 +30,7 @@ def main():
                         nargs='?',
                         type=argparse.FileType('r'),
                         help='YAML file with the configuration of the MP/SoC')
+
     parser.add_argument('-o','--output',
                         nargs='?',
                         type=pathlib.Path,
@@ -42,11 +45,17 @@ def main():
                         action='store_true',
                         help='Enable debug mode')
 
+    parser.add_argument('-m','--mmap',
+                        action='store_true',
+                        help='Print memory map of each SoC')
+
+
     in_args = {}
     in_args['config']   = parser.parse_args().cfg
     in_args['output']   = parser.parse_args().output
     in_args['validate'] = parser.parse_args().validate
     in_args['debug']    = parser.parse_args().debug
+    in_args['mmap']     = parser.parse_args().mmap
 
     handler = logging.StreamHandler()
     handler.setFormatter(CustomFormatter())
@@ -65,7 +74,7 @@ def main():
             if in_args['validate'] == True:
                 logging.info('Validate only enabled, exiting now...')
                 sys.exit(0)
-            _gen(cfg, in_args['output'])
+            _gen(cfg, in_args['output'], in_args['mmap'])
 
 if __name__ == '__main__':
     main()
